@@ -536,4 +536,69 @@ class FastACELoss3DV2(nn.Module):
 
         # elastic
         elastic = torch.sum((self.alpha + self.beta * curvature ** 2) * length)
+        return region + elastic
+
+
+
+
+class FastACELoss3DV3(nn.Module):
+    """
+    Active contour based elastic model loss
+    based on minpooling & maxpooling and laplace filter
+    """
+
+    def __init__(self, miu=1.0, alpha=1e-3, beta=2.0, classes=4, types="other", smooth = 1e+3):
+        super(FastACELoss3DV3, self).__init__()
+        self.miu = miu
+        self.alpha = alpha
+        self.beta = beta
+        self.classes = classes
+        self.types = types
+        laplace_kernel = np.ones((3, 3, 3))
+        laplace_kernel[1, 1, 1] = -26
+        self.smooth = smooth
+
+        self.laplace = nn.Parameter(
+            torch.from_numpy(laplace_kernel).float().unsqueeze(
+                0).unsqueeze(0).expand(self.classes, 1, 3, 3, 3),
+            requires_grad=False)
+
+        self.laplace_operator = nn.Conv3d(self.classes, self.classes, groups=self.classes, kernel_size=3, stride=1,
+                                          padding=1,
+                                          bias=False)
+        self.laplace_operator.weight = self.laplace
+
+    def forward(self, predication, label):
+        min_pool_x = nn.functional.max_pool3d(predication * -1, 3, 1, 1) * -1
+        contour = torch.relu(nn.functional.max_pool3d(
+            min_pool_x, 3, 1, 1) - min_pool_x)
+
+        diff = self.laplace_operator(predication)
+
+        # length
+        length = torch.abs(contour)
+
+        # curvature
+        if self.types:
+            curvature = torch.abs(diff)
+            curvature = (curvature - curvature.min()) / \
+                (curvature.max() - curvature.min() + 1e-8)
+        else:
+            """
+            maybe more powerful
+            """
+            curvature = torch.abs(diff) / ((length ** 2 + 1) ** 0.5 + 1e-8)
+            curvature = (curvature - curvature.min()) / \
+                (curvature.max() - curvature.min() + 1e-8)
+        # region
+        label = label.float()
+        c_in = torch.ones_like(predication)
+        c_out = torch.zeros_like(predication)
+        region_in = torch.abs(torch.sum(predication * ((label - c_in) ** 2))) / self.smooth
+        region_out = torch.abs(
+            torch.sum((1 - predication) * ((label - c_out) ** 2))) / self.smooth
+        region = self.miu * region_in + region_out
+
+        # elastic
+        elastic = torch.sum((self.alpha + self.beta * curvature ** 2) * length) / self.smooth
         return region + elastic
\ No newline at end of file
