@@ -14,6 +14,7 @@ class Inference(object):
         self.sigma = sigma
         self.device = device
         self.step_size = step_size
+
         if filter == 'gaussian' and len(patch_size) == 3:
             self.filter = self.create_3D_filter().to(device)
 
@@ -21,9 +22,6 @@ class Inference(object):
         self.save_path = save_path
         self.score = []
         self.iter_score =[]
-
-
-    def new_epoch(self):
         self.is_end = False
         self.current_coordinates = np.array([1,1,1])
         self.current_index = 0
@@ -43,7 +41,6 @@ class Inference(object):
             model.eval()
             patch = self.get_inference_patch()
             output = model(patch.unsqueeze(0).float().to(self.device)).squeeze(0)[0]
-            output = output * self.filter
             output = output.detach().cpu()
             lower_bound, upper_bound = self.get_patch_bound()
             self.result_map[:, lower_bound[0]:upper_bound[0], lower_bound[1]:upper_bound[1], lower_bound[2]:upper_bound[2]] = output + self.result_map[: , lower_bound[0]:upper_bound[0],lower_bound[1]:upper_bound[1], lower_bound[2]:upper_bound[2]]
@@ -89,18 +86,41 @@ class Inference(object):
         return np.all(self.current_coordinates * (self.patch_size * self.step_size + 1) >= self.images.shape) #다음번 grid가 넘칠 경우
 
     def save_inference_result(self):
-        self.result_map = self.result_map[: , self.pad_bounds[0]:-self.pad_bounds[1], self.pad_bounds[2]:-self.pad_bounds[3], self.pad_bounds[4]:-self.pad_bounds[5]]
-        self.result_map = torch.argmax(self.result_map.permute(1,2,3,0), dim = -1)
+        if self.pad_bounds[1] == 0:
+            self.result_map = self.result_map[: , self.pad_bounds[0]:,:, :]
+        else:
+            self.result_map = self.result_map[: , self.pad_bounds[0]:-self.pad_bounds[1],:, :]
+
+        if self.pad_bounds[3] == 0:
+            self.result_map = self.result_map[: , :, self.pad_bounds[2]:, :]
+        else:
+            self.result_map = self.result_map[: , :, self.pad_bounds[2]:-self.pad_bounds[3], :]
+        
+        if self.pad_bounds[5] == 0:
+            self.result_map = self.result_map[: , :, :, self.pad_bounds[4]:]
+        else:
+            self.result_map = self.result_map[: , :, :, self.pad_bounds[4]:-self.pad_bounds[5]]
+        
+        self.result_map = F.softmax(self.result_map.permute(1,2,3,0), dim = -1)
+        self.result_map = torch.argmax(self.result_map, dim = -1).long()
         if self.mode == 'save':
-            np.savez(self.save_path+"result_"+"{0:003d}".format(self.current_index)+".npz", x = self.result_map.detach().cpu(), y = None)
+            np.savez(self.save_path+"result_"+"{0:003d}".format(self.current_index)+".npz", x = self.result_map.detach().cpu(), y = self.dataset[self.current_index][1])
         
         elif self.mode == 'dice':
-            seg = self.dataset[self.current_index][0]
-            self.result_map[torch.where(self.result_map == 0)] = -1
-            intersection = (self.result_map == seg).sum()
-            union = (self.result_map != -1).sum() + (seg != 0).sum()
-            self.iter_score.append(intersection *2 / union)
+            seg = self.dataset[self.current_index][1]
+            result = []
+            for i in range(1, self.n_classes):
+                temp_seg = (seg == i)
+                temp_img = (self.result_map == i)
+                intersection = (temp_seg * temp_img).sum()
+                union = temp_seg.sum() + temp_img.sum()
+                dice = 2 * intersection / union
+                result.append(dice.numpy())
+            self.iter_score.append(result)
     
+    def get_result(self):
+        return np.mean(np.array(self.iter_score), axis = 0)
+
     def check_end(self):
         if self.current_index == len(self.dataset) - 1:
             self.is_end = True
