@@ -232,7 +232,7 @@ class Deep_Supervision_UNet3d(nn.Module):
 
         conv_kwargs1 = {'kernel_size' : 3, 'padding' : 1,  'stride' : 1}
         conv_kwargs2 = {'kernel_size' : 3, 'stride' : 1, 'padding':1}
-        transp_kwargs = {'kernel_size' : 2, 'stride' : 1, 'stride' : 2}
+        transp_kwargs = {'kernel_size' : 3, 'padding' : 1, 'stride' : 2}
 
 
         self.decoder1_trans = ConvDropoutNormNonlin(320, 256, conv_kwargs= transp_kwargs, conv_op = nn.ConvTranspose3d)
@@ -282,10 +282,10 @@ class Deep_Supervision_UNet3d(nn.Module):
         x4 = self.encoder4(x3)
         x5 = self.encoder5(x4)
 
-        x4_ = self.decoder1_conv(torch.cat((x4, self.decoder1_trans(x5)), dim = 1))
-        x3_ = self.decoder2_conv(torch.cat((x3, self.decoder2_trans(x4_)), dim = 1))
-        x2_ = self.decoder3_conv(torch.cat((x2, self.decoder3_trans(x3_)), dim = 1))
-        x1_ = self.decoder4_conv(torch.cat((x1, self.decoder4_trans(x2_)), dim = 1))
+        x4_ = self.decoder1_conv(torch.cat((x4, self.decoder1_trans(x5, output_size = (x4.shape[-3], x4.shape[-2], x4.shape[-1]))), dim = 1))
+        x3_ = self.decoder2_conv(torch.cat((x3, self.decoder2_trans(x4_, output_size = (x3.shape[-3], x3.shape[-2], x3.shape[-1]))), dim = 1))
+        x2_ = self.decoder3_conv(torch.cat((x2, self.decoder3_trans(x3_, output_size = (x2.shape[-3], x2.shape[-2], x2.shape[-1]))), dim = 1))
+        x1_ = self.decoder4_conv(torch.cat((x1, self.decoder4_trans(x2_, output_size = (x1.shape[-3], x1.shape[-2], x1.shape[-1]))), dim = 1))
 
         if not self.is_binary:
             x1_ = F.softmax(self.final_layer1(x1_).view(bs, self.final_output_channels, -1), dim = 1).view(bs, self.final_output_channels, nx, ny, nz)
@@ -440,72 +440,7 @@ class Interactive_Model(nn.Module):
 
 
 
-class Daegu_Model10(nn.Module):
-    def __init__(self, patch_size, resnet_output = 4):
-        super().__init__()
-        resnet_output = resnet_output
-        out_tconv1 = resnet_output//2
-        out_tconv2 = out_tconv1//2
-        kwargs = {'sample_input_D':patch_size[0], 'sample_input_H':patch_size[1], 'sample_input_W':patch_size[2],'num_seg_classes':resnet_output}
-        self.model = resnet10(**kwargs)
 
-        self.upsample1 = nn.Sequential(nn.ConvTranspose3d(in_channels = resnet_output, out_channels= out_tconv1, kernel_size =3 , stride = 2, padding = 1, output_padding =1),
-                                       nn.InstanceNorm3d(out_tconv1),
-                                       nn.LeakyReLU())
-        
-        self.upsample2 = nn.Sequential(nn.ConvTranspose3d(in_channels = out_tconv1, out_channels= out_tconv2, kernel_size =3 , stride = 2, padding = 1, output_padding =1),
-                                       nn.InstanceNorm3d(out_tconv2),
-                                       nn.LeakyReLU())
-        
-        self.final_layer = nn.Sequential(nn.Conv3d(in_channels = out_tconv2, out_channels = 2, kernel_size = 3, stride = 1, padding = 1),
-                                   nn.InstanceNorm3d(2),
-                                   nn.LeakyReLU())
-
-    def forward(self, X):
-        X = self.model(X)
-        X = self.upsample1(X)
-        X = self.upsample2(X)
-        X = self.final_layer(X)
-        return torch.softmax(X, dim = -1)
-
-class Daegu_Model34(nn.Module):
-    def __init__(self, patch_size, input_channel = 1, output_channel= 2):
-        super().__init__()
-        out_channel1 = 1
-        out_channel2 = out_channel1 * 4
-
-        self.a_conv1 = nn.Sequential(nn.Conv3d(in_channels = input_channel, out_channels = out_channel1, kernel_size = 3, stride = 1, padding = 6, dilation = 6),
-                                   nn.InstanceNorm3d(out_channel1),
-                                   nn.LeakyReLU())
-        self.a_conv2 = nn.Sequential(nn.Conv3d(in_channels = input_channel, out_channels = out_channel1, kernel_size = 3, stride = 1, padding = 12, dilation = 12),
-                                   nn.InstanceNorm3d(out_channel1),
-                                   nn.LeakyReLU())
-        self.a_conv3 = nn.Sequential(nn.Conv3d(in_channels = input_channel, out_channels = out_channel1, kernel_size = 3, stride = 1, padding = 18, dilation = 18),
-                                   nn.InstanceNorm3d(out_channel1),
-                                   nn.LeakyReLU())
-        self.a_conv4 = nn.Sequential(nn.Conv3d(in_channels = input_channel, out_channels = out_channel1, kernel_size = 1, stride = 1, padding = 0, dilation = 1),
-                                   nn.InstanceNorm3d(out_channel1),
-                                   nn.LeakyReLU())
-
-        self.a_conv2_1 = nn.Sequential(nn.Conv3d(in_channels = out_channel2, out_channels = out_channel2, kernel_size = 1, stride = 1, padding = 0, dilation = 1),
-                                   nn.InstanceNorm3d(out_channel2),
-                                   nn.LeakyReLU())
-
-        self.last_layer = nn.Sequential(nn.Conv3d(in_channels = out_channel2, out_channels = output_channel, kernel_size = 1, stride = 1, padding = 0, dilation = 1),
-                                   nn.InstanceNorm3d(output_channel),
-                                   nn.LeakyReLU())
-
-
-    def forward(self, X):
-        X1 = self.a_conv1(X)
-        X2 = self.a_conv2(X)
-        X3 = self.a_conv3(X)
-        X4 = self.a_conv4(X)
-
-        X = torch.cat((X1,X2,X3,X4), dim = 1)
-        X = self.a_conv2_1(X)
-        X = self.last_layer(X)
-        return torch.softmax(X, dim = -1)
 
 
 
