@@ -43,10 +43,10 @@ class Batch_Affine_3D(object):
         for batch_index in range(bs):
             transformed_coords = self.gpu_calculate_coornidates(self.coords, self.matrices, img_size).long() #coorniates를 Affine 변환
             if not seg:
-                images[batch_index, :, :, :, :] = self.pad_image_seg(images[batch_index, :, transformed_coords[0], transformed_coords[1], transformed_coords[2]], patch_size)
+                images[batch_index, :, :, :, :] = images[batch_index, :, transformed_coords[0], transformed_coords[1], transformed_coords[2]]
                 images = images.reshape(bs, n_modalities, nx, ny, nz)
             else:
-                images[batch_index, :, :, :] = self.pad_image_seg(images[batch_index, transformed_coords[0], transformed_coords[1], transformed_coords[2]], patch_size)
+                images[batch_index, :, :, :] = images[batch_index, transformed_coords[0], transformed_coords[1], transformed_coords[2]]
                 images = images.reshape(bs, nx, ny, nz)
             
         return images
