@@ -4,6 +4,7 @@ import pickle
 import os
 import SimpleITK as sitk
 import torch.nn.functional as F
+import copy
 
 class Normalizer(object):
     def __init__(self, percentile_clipping_ratio = None):
@@ -69,14 +70,17 @@ class Fixed_Normalizer(object):
         return images
 
 class Cropping(object):
-    def __call__(self, images, seg = None, mode = 'train'):
-        non_zero_index = np.where(images != 0)
+    def __call__(self, images, seg = None, mode = 'train', is_CT = True):
+        temp = copy.deepcopy(images)
+        if is_CT:
+            temp[np.where(temp < - 700)] = 0
+        non_zero_index = np.where(temp.astype(int) != 0)
         min_val = np.min(non_zero_index, axis = 1)
         max_val = np.max(non_zero_index, axis = 1)
         if mode == 'train':
-            return images[:, min_val[-3]:max_val[-3], min_val[-2]:max_val[-2], min_val[-1]:max_val[-1]], seg[min_val[-3]:max_val[-3], min_val[-2]:max_val[-2], min_val[-1]:max_val[-1]]
+            return images[:, min_val[-3]:max_val[-3]+1, min_val[-2]:max_val[-2]+1, min_val[-1]:max_val[-1]+1], seg[ min_val[-3]:max_val[-3]+1, min_val[-2]:max_val[-2]+1, min_val[-1]:max_val[-1]+1]
         if mode == 'test':
-            return images[:, min_val[-3]:max_val[-3], min_val[-2]:max_val[-2], min_val[-1]:max_val[-1]]
+            return images[:, min_val[-3]:max_val[-3]+1, min_val[-2]:max_val[-2]+1, min_val[-1]:max_val[-1]+1]
 
 
 class Resampling(object):
