@@ -126,6 +126,8 @@ class Trainer(object):
                         loss.backward()
                         return loss
                     self.optimizer.step(closure)
+                    epoch_tr_loss = 1
+                    epoch_tr_div = 1
                 
                 else:
                     output = self.model(images)
@@ -133,9 +135,8 @@ class Trainer(object):
                     loss = self.calculate_loss(output, seg, writer, current_iter)
                     loss.backward()
                     self.optimizer.step()
-
-                epoch_tr_loss += loss.item()
-                epoch_tr_div += 1
+                    epoch_tr_loss += loss.item()
+                    epoch_tr_div += 1
 
                 if self.tr_dl.current_index < 3 and not isinstance(self.optimizer, SAMSGD) and self.visualization:
                     print("###########", self.tr_dl.current_index, "###########")
